# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceSubmissionStatusResponse(Model):
    """EnergyStarPlaceSubmissionStatusResponse.

    :param place_id: The place identifier
    :type place_id: int
    :param place_name: The place name
    :type place_name: str
    :param place_size:
    :type place_size: ~energycap.sdk.models.PlaceSizeChild
    :param place_submission_status: The list of submission periods and the
     submission status for each period
    :type place_submission_status:
     list[~energycap.sdk.models.EnergyStarPlaceSubmissionStatusChild]
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_name': {'key': 'placeName', 'type': 'str'},
        'place_size': {'key': 'placeSize', 'type': 'PlaceSizeChild'},
        'place_submission_status': {'key': 'placeSubmissionStatus', 'type': '[EnergyStarPlaceSubmissionStatusChild]'},
    }

    def __init__(self, place_id=None, place_name=None, place_size=None, place_submission_status=None):
        super(EnergyStarPlaceSubmissionStatusResponse, self).__init__()
        self.place_id = place_id
        self.place_name = place_name
        self.place_size = place_size
        self.place_submission_status = place_submission_status
